QueueRemoveAction class

QueueRemove action to remove a member from a queue.

Inheritance
Annotations
  • @immutable

Constructors

QueueRemoveAction({required String queue, required String interface, String? actionId})

Properties

actionId String?
Unique action ID for tracking responses. Auto-generated if null.
final
hashCode int
The hash code for this object.
no setterinherited
interface String
final
name String
The action name (e.g., 'Login', 'Originate', 'Ping').
no setteroverride
parameters Map<String, String>
Action parameters as key-value pairs.
no setteroverride
queue String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, String>
Converts this action to a map for transmission.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited