registerResponse method

Stream<Response> registerResponse(
  1. String actionID
)
inherited

Registers a listener for responses with a specific actionID.

Each action sent to the server should have a unique ActionID. This method creates a stream that emits responses matching that ID.

Implementation

Stream<Response> registerResponse(String actionID) {
  if (!_respListeners.containsKey(actionID)) {
    _respListeners[actionID] = StreamController<Response>.broadcast();
  }
  return _respListeners[actionID]!.stream;
}