readEvent method
Waits for and returns the first occurrence of an event with name.
This is a convenience method that automatically unsubscribes after receiving the first matching event.
Implementation
Future<Event> readEvent(String name) async {
return registerEvent(name).first;
}