KeepAliveConfig class

Keep-alive configuration for Ping/Pong.

Constructors

KeepAliveConfig({Duration interval = const Duration(seconds: 30), Duration timeout = const Duration(seconds: 10), bool enabled = true})
const

Properties

enabled bool
Whether keep-alive is enabled
final
hashCode int
The hash code for this object.
no setterinherited
interval Duration
Interval between ping messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
Timeout for pong response
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited