LifeCycle mixin
Lifecycle management mixin for AMI components.
Provides init() and dispose() hooks for resource management.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Clean up resources. Called when component is no longer needed.
-
init(
) → void - Initialize resources. Called before using the component.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited