Reader mixin

Mixin for receiving and processing AMI protocol messages.

Provides callbacks for handling responses, events, and greeting messages.

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onReadEvent(Event event) → void
Called when an AMI event is received.
onReadGreeting(String words) → void
Called when the server greeting message is received.
onReadResponse(Response response) → void
Called when an AMI response is received.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited