ReconnectionConfig class

Configuration for connection retry behavior.

Constructors

ReconnectionConfig({int maxAttempts = 5, Duration initialDelay = const Duration(seconds: 1), Duration maxDelay = const Duration(seconds: 30), double backoffMultiplier = 2.0})
const

Properties

backoffMultiplier double
Multiplier for exponential backoff
final
hashCode int
The hash code for this object.
no setterinherited
initialDelay Duration
Initial delay between reconnection attempts
final
maxAttempts int
Maximum number of reconnection attempts (0 = infinite)
final
maxDelay Duration
Maximum delay between reconnection attempts
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delayForAttempt(int attempt) Duration
Calculates the delay for a given attempt number.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited