Sender mixin
Mixin that combines connection and dispatching capabilities for sending actions.
Provides high-level API for sending AMI actions and receiving responses.
- Superclass constraints
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- prefix ↔ String?
-
Prefix for generating unique action IDs.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statusStream
→ Stream<
bool> ? -
Stream of connection status changes (true = connected, false = disconnected).
no setterinherited
Methods
-
available(
) → bool -
Returns true if connected and ready to send data.
inherited
-
connect(
String host, int port, {dynamic args}) → Future< void> -
Establishes a connection to the AMI server.
inherited
-
disconnect(
) → void -
Closes the connection to the AMI server.
inherited
-
dispose(
) → void -
Clean up resources. Called when component is no longer needed.
inherited
-
init(
) → void -
Initialize resources. Called before using the component.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onReadEvent(
Event event) → void -
Called when an AMI event is received.
inherited
-
onReadGreeting(
String words) → void -
Called when the server greeting message is received.
inherited
-
onReadResponse(
Response response) → void -
Called when an AMI response is received.
inherited
-
readAllEventsUntil(
String name, String eventPredicate) → Future< List< Event> > -
Collects all events of type
nameuntileventPredicateevent occurs.inherited -
readEvent(
String name) → Future< Event> -
Waits for and returns the first occurrence of an event with
name.inherited -
registerEvent(
String name) → Stream< Event> -
Registers a listener for a specific event name.
inherited
-
registerResponse(
String actionID) → Stream< Response> -
Registers a listener for responses with a specific
actionID.inherited -
send(
Map< String, String> data) → void -
Sends data to the AMI server.
inherited
-
sendAction(
String name, {String? id, Map< String, String> ? args, Duration? timeout}) → Future<Response?> - Sends an AMI action and returns the response.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited