WebSocketConnector mixin
- Superclass constraints
- Implemented types
-
- Mixin applications
-
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
statusStream
→ Stream<bool>?
-
Stream of connection status changes (true = connected, false = disconnected).
no setteroverride
Methods
-
available()
→ bool
-
Returns true if connected and ready to send data.
override
-
connect(String host, int port, {dynamic args})
→ Future<void>
-
Establishes a connection to the AMI server.
override
-
disconnect()
→ void
-
Closes the connection to the AMI server.
override
-
dispose()
→ void
-
Clean up resources. Called when component is no longer needed.
override
-
handleMessage(dynamic message)
→ void
-
Handles incoming message data and converts it to AMI messages.
inherited
-
init()
→ void
-
Initialize resources. Called before using the component.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
send(Map<String, String> data)
→ void
-
Sends data to the AMI server.
override
-
toString()
→ String
-
A string representation of this object.
inherited