WebSocketMessageParser mixin

Parser for WebSocket AMI messages in JSON format.

Handles the WebSocket protocol wrapper around standard AMI messages.

Superclass constraints
Implemented types
Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Clean up resources. Called when component is no longer needed.
override
handleMessage(dynamic message) → void
Handles incoming message data and converts it to AMI messages.
override
init() → void
Initialize resources. Called before using the component.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onReadEvent(Event event) → void
Called when an AMI event is received.
inherited
onReadGreeting(String words) → void
Called when the server greeting message is received.
inherited
onReadResponse(Response response) → void
Called when an AMI response is received.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited