MessageParser class abstract
Interface for parsing AMI protocol messages.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseMessage(
String rawData) → AmiMessage? - Parses raw string data into an AMI message.
-
parseMultiple(
String rawData) → List< AmiMessage> - Parses multiple messages from buffered data.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited