Connector mixin
Mixin for managing network connections to the AMI server.
Provides connection lifecycle and data transmission capabilities.
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statusStream
→ Stream<
bool> ? -
Stream of connection status changes (true = connected, false = disconnected).
no setter
Methods
-
available(
) → bool - Returns true if connected and ready to send data.
-
connect(
String host, int port, {dynamic args}) → Future< void> - Establishes a connection to the AMI server.
-
disconnect(
) → void - Closes the connection to the AMI server.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
Map< String, String> data) → void - Sends data to the AMI server.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited