EnhancedActions mixin
Enhanced actions with modern AMI features.
@deprecated Use the Clean Architecture API instead (ami_client_plus.dart) This legacy code will be removed in v2.0.0
Extends the basic actions with type-safe implementations and modern AMI protocol features.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearEventFilters(
) → Future< AmiResponse?> - Clears all event filters.
-
hangup(
String channel, {int? cause}) → Future< AmiResponse?> - Hangs up a channel.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
originate(
{required String channel, required String extension, required String context, String? callerId, int priority = 1, int timeout = 30000, bool async = false}) → Future< AmiResponse?> - Originates a call from a channel to an extension.
-
ping(
) → Future< AmiResponse?> - Sends a Ping action to keep the connection alive.
-
pjsipShowEndpoints(
) → Future< AmiResponse?> - Retrieves the list of PJSIP endpoints.
-
reload(
{String? module}) → Future< AmiResponse?> - Reloads Asterisk configuration.
-
sendAction(
String name, {String? id, Map< String, String> ? args, Duration? timeout}) → Future<AmiResponse?> - Sends an action - must be implemented by the using class
-
setEventFilter(
String filter) → Future< AmiResponse?> - Enables or disables event filtering on the server.
-
sipPeers(
) → Future< AmiResponse?> - Retrieves the list of SIP peers.
-
status(
) → Future< AmiResponse?> - Retrieves system status with all channels.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited